@@ -3,4 +3,4 @@ from .apiaries import Apiaries, HoneyTypes
 from .hives import Hives, HiveConditions
 from .swarms import Swarms, SwarmHealthStatuses
 from .events import Events, EventStatuses, EventTypes
-from .comments import Comments, CommentTypes
+from .comments import Comments
